@@ -345,18 +345,21 @@ class Project:
 
             image_id = image['id']
 
-            image_details = self._ecr(
+            ecr = self._ecr(
                 account_id=image.get('account_id'),
                 region_name=image.get('region_name'),
                 role_arn=image.get('role_arn')
-            ).describe_image(
+            )
+
+            image_details = ecr.describe_image(
                 namespace=image.get('namespace', self.namespace),
                 image_id=image_id,
                 tag=from_label,
                 account_id=image.get('account_id')
             )
 
-            release_images[image_details['image_id']] = image_details['ref']
+            if image_details:
+                release_images[image_details['image_id']] = image_details['ref']
 
         return release_images
 
